import { createDevAppRunner } from '../../runtime/start';
import * as Layout from '../layout';
import * as Plugin from '../plugin';
import { serializeError } from '../utils';
import { isReflectionStage } from './stage';
import { writeArtifacts } from './typegen';
async function run() {
    if (!process.env.NEXUS_REFLECTION_LAYOUT) {
        throw new Error('process.env.NEXUS_REFLECTION_LAYOUT is required');
    }
    const app = require('../../').default;
    const layout = Layout.createFromData(JSON.parse(process.env.NEXUS_REFLECTION_LAYOUT));
    const appRunner = createDevAppRunner(layout, app, {
        catchUnhandledErrors: false,
    });
    try {
        await appRunner.start();
    }
    catch (err) {
        sendErrorToParent(err);
    }
    if (isReflectionStage('typegen')) {
        try {
            const plugins = Plugin.importAndLoadRuntimePlugins(app.private.state.plugins);
            await writeArtifacts({
                graphqlSchema: app.private.state.assembled.schema,
                layout,
                schemaSettings: app.settings.current.schema,
                plugins,
            });
            sendDataToParent({
                type: 'success-typegen',
            });
            return;
        }
        catch (err) {
            sendErrorToParent(err);
        }
    }
    function sendDataToParent(message) {
        if (!process.send) {
            throw new Error('process.send is undefined, could not send the plugins back to the main process');
        }
        process.send(message);
    }
    function sendErrorToParent(err) {
        sendDataToParent({ type: 'error', data: { serializedError: serializeError(err) } });
    }
}
run();
//# sourceMappingURL=fork-script.js.map