import * as NexusSchema from '@nexus/schema';
import { createNexusSchemaStateful } from '../../lib/nexus-schema-stateful';
import { assertAppNotAssembled } from '../utils';
import { log } from './logger';
import { createSchemaSettingsManager } from './settings';
import { mapSettingsAndPluginsToNexusSchemaConfig } from './settings-mapper';
function createLazyState() {
    return {
        contextContributors: [],
        plugins: [],
    };
}
export function create(appState) {
    appState.schemaComponent = createLazyState();
    const statefulNexusSchema = createNexusSchemaStateful();
    const settings = createSchemaSettingsManager();
    const api = Object.assign(Object.assign({}, statefulNexusSchema.builders), { use(plugin) {
            assertAppNotAssembled(appState, 'app.schema.use', 'The Nexus Schema plugin you used will be ignored.');
            appState.schemaComponent.plugins.push(plugin);
        },
        addToContext(contextContributor) {
            appState.schemaComponent.contextContributors.push(contextContributor);
        },
        middleware(fn) {
            api.use(NexusSchema.plugin({
                // TODO: Do we need to expose the name property?
                name: 'local-middleware',
                onCreateFieldResolver(config) {
                    return fn(config);
                },
            }));
        } });
    return {
        public: api,
        private: {
            settings: settings,
            reset() {
                statefulNexusSchema.state.types = [];
                appState.schemaComponent.contextContributors = [];
                appState.schemaComponent.plugins = [];
            },
            assemble: (plugins) => {
                const nexusSchemaConfig = mapSettingsAndPluginsToNexusSchemaConfig(plugins, settings.data);
                nexusSchemaConfig.types.push(...statefulNexusSchema.state.types);
                nexusSchemaConfig.plugins.push(...appState.schemaComponent.plugins);
                const { schema, missingTypes } = NexusSchema.core.makeSchemaInternal(nexusSchemaConfig);
                return { schema, missingTypes };
            },
            checks() {
                NexusSchema.core.assertNoMissingTypes(appState.assembled.schema, appState.assembled.missingTypes);
                if (statefulNexusSchema.state.types.length === 0) {
                    log.warn(emptyExceptionMessage());
                }
            },
        },
    };
}
function emptyExceptionMessage() {
    return `Your GraphQL schema is empty. This is normal if you have not defined any GraphQL types yet. If you did however, check that your files are contained in the same directory specified in the \`rootDir\` property of your tsconfig.json file.`;
}
//# sourceMappingURL=schema.js.map