/// <reference types="node" />
import { Express } from 'express';
import { GraphQLSchema } from 'graphql';
import * as HTTP from 'http';
import * as Plugin from '../../lib/plugin';
import { MaybePromise } from '../../lib/utils';
import { AppState } from '../app';
export declare type NexusRequestHandler = (req: HTTP.IncomingMessage, res: HTTP.ServerResponse) => void;
export interface Server {
    express: Express;
    handlers: {
        playground: NexusRequestHandler;
        graphql: NexusRequestHandler;
    };
}
export declare const defaultState: {
    running: boolean;
    httpServer: HTTP.Server;
    createContext: null;
};
export declare function create(appState: AppState): {
    private: {
        settings: {
            change: (newSettings: import("./settings").SettingsInput) => void;
            reset: () => void;
            data: Readonly<import("./settings").SettingsData>;
        };
        state: {
            running: boolean;
            httpServer: HTTP.Server;
            createContext: null;
        };
        reset(): void;
        assemble(loadedRuntimePlugins: Plugin.RuntimeContributions[], schema: GraphQLSchema): {
            createContext: ContextCreator<Record<string, any>, Record<string, any>>;
        };
        start(): Promise<void>;
        stop(): Promise<void>;
    };
    public: Server;
};
declare type AnonymousRequest = Record<string, any>;
declare type AnonymousContext = Record<string, any>;
export declare type ContextCreator<Req extends AnonymousRequest = AnonymousRequest, Context extends AnonymousContext = AnonymousContext> = (req: Req) => MaybePromise<Context>;
export {};
//# sourceMappingURL=server.d.ts.map