"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rightOrFatal = exports.rightOrThrow = exports.getRight = exports.getLeft = exports.globalToLocalModule = void 0;
const tslib_1 = require("tslib");
const Either_1 = require("fp-ts/lib/Either");
const Path = tslib_1.__importStar(require("path"));
const fs_1 = require("../fs");
const process_1 = require("../process");
/**
 * Handoff execution from a global to local version of a package.
 *
 * If the givne global module path is not a real node package (defined as being
 * unable to locate its package.json file) then an error will be thrown.
 */
function globalToLocalModule(input) {
    var _a;
    const globalProjectDir = (_a = fs_1.findFileRecurisvelyUpwardSync('package.json', {
        cwd: Path.dirname(input.globalPackageFilename),
    })) === null || _a === void 0 ? void 0 : _a.dir;
    if (!globalProjectDir) {
        throw new Error(`Could not perform handoff to local package version becuase the given global package does not appear to actually be a package:\n\n${input.globalPackageFilename}`);
    }
    require(Path.join(input.localPackageDir, Path.relative(globalProjectDir, input.globalPackageFilename)));
}
exports.globalToLocalModule = globalToLocalModule;
/**
 * Extract the left value from an Either.
 */
function getLeft(e) {
    if (Either_1.isLeft(e))
        return e.left;
    return undefined;
}
exports.getLeft = getLeft;
/**
 * Extract the right value from an Either.
 */
function getRight(e) {
    if (Either_1.isRight(e))
        return e.right;
    return undefined;
}
exports.getRight = getRight;
/**
 * Extract the right value from an Either or throw.
 */
function rightOrThrow(x) {
    if (Either_1.isLeft(x))
        throw x.left;
    return x.right;
}
exports.rightOrThrow = rightOrThrow;
/**
 * Extract the right value from an Either or throw.
 */
function rightOrFatal(x) {
    if (Either_1.isLeft(x))
        process_1.fatal(x.left);
    return x.right;
}
exports.rightOrFatal = rightOrFatal;
//# sourceMappingURL=utils.js.map