"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSchemaSettingsManager = exports.changeSettings = void 0;
const tslib_1 = require("tslib");
const Lo = tslib_1.__importStar(require("lodash"));
const connectionPluginConfigManagedByNexus = {
    nexusSchemaImportId: 'nexus/components/schema',
    /**
     * The name of the relay connection field builder. This is not configurable by users.
     */
    nexusFieldName: 'connection',
};
/**
 * Mutate the settings data with new settings input.
 */
function changeSettings(state, newSettings) {
    if (newSettings.nullable) {
        Lo.merge(state.nullable, newSettings.nullable);
    }
    if (newSettings.generateGraphQLSDLFile) {
        state.generateGraphQLSDLFile = newSettings.generateGraphQLSDLFile;
    }
    if (newSettings.rootTypingsGlobPattern) {
        state.rootTypingsGlobPattern = newSettings.rootTypingsGlobPattern;
    }
    if (newSettings.connections) {
        // todo deep merge
        Object.assign(state.connections, Object.assign(Object.assign({}, newSettings.connections), connectionPluginConfigManagedByNexus));
    }
}
exports.changeSettings = changeSettings;
/**
 * Get the default settings.
 */
function defaultSettings() {
    const data = {
        nullable: {
            inputs: true,
            outputs: true,
        },
        generateGraphQLSDLFile: 'api.graphql',
        rootTypingsGlobPattern: './**/*.ts',
        connections: {
            // there is another level of defaults that will be applied by Nexus Schema Relay Connections plugin
            default: Object.assign({}, connectionPluginConfigManagedByNexus),
        },
        authorization: {}
    };
    return data;
}
/**
 * Create a schema settings manager.
 */
function createSchemaSettingsManager() {
    const data = defaultSettings();
    function change(newSettings) {
        return changeSettings(data, newSettings);
    }
    function reset() {
        for (const k of Object.keys(data)) {
            delete data[k];
        }
        Object.assign(data, defaultSettings());
    }
    return {
        change,
        reset,
        data,
    };
}
exports.createSchemaSettingsManager = createSchemaSettingsManager;
//# sourceMappingURL=settings.js.map